==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/ar.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "رابط عمومي",
    "Photos" : "الصور",
    "On This Day" : "في هذا اليوم",
    "Your memories under your control" : "ذكرياتك تحت يديك",
    "All media" : "كل الوسائط",
    "Videos" : "مقاطع الفيديو",
    "Albums" : "الألبومات",
    "Collaborative albums" : "ألبومات تعاونية",
    "People" : "الأشخاص",
    "Folders" : "المجلدات",
    "Favorites" : "المُفضّلة",
    "On this day" : "في هذا اليوم",
    "Shared with you" : "تمّت مُشارَكته معك",
    "Tags" : "الوسوم",
    "Places" : "أماكن",
    "Map" : "خريطة",
    "Photos settings" : "إعدادات الصور",
    "Mark selection as favorite" : "تحديد المفضلة",
    "Add selection to favorites" : "إضافة ما تمّ تحديده إلى المفضلة",
    "Remove selection from favorites" : "حذف ما تمّ تحديده من المفضلة",
    "Name of the album" : "اسم الألبوم",
    "Location of the album" : "موقع الألبوم",
    "Back" : "عودة",
    "Add collaborators" : "أضِف المتعاونين",
    "Save" : "حفظ",
    "Create album" : "إنشاء ألبوم",
    "Add to Album" : "إضافة إلى الألبوم",
    "Add selection to album {albumName}" : "إضافة ما تمّ تحديده إلى الألبوم {albumName}",
    "Shared by" : "تمّت مُشارَكته من قِبَل",
    "Create a new album." : "إنشِيء ألبوماً جديداً.",
    "Create new album" : "إنشاء ألبوم جديد",
    "New album" : "ألبوم جديد",
    "_%n item_::_%n photos and videos_" : ["%n صور ومقاطع الفيديو","%n عنصر","%n صور ومقاطع الفيديو","%n صور ومقاطع الفيديو","%n صور ومقاطع الفيديو","%n صور ومقاطع الفيديو"],
    "Failed to fetch collaborators list." : "تعذّر جلب قائمة المتعاونين.",
    "Failed to update album." : "تعذّر تحديث الألبوم.",
    "Add people or groups who can edit your album" : "إضِف الأشخاص أو المجموعات الذين يحق لهم تعديل ألبومك",
    "Search people or groups" : "البحث عن أشخاص أو مجموعات",
    "No recommendations. Start typing." : "لا توجد توصيات. ابدأ بالكتابة.",
    "Group" : "مجموعة",
    "Remove {collaboratorLabel} from the collaborators list" : "حذف {collaboratorLabel} من قائمة المتعاونين",
    "Copy the public link" : "إنسَخ الرابط العمومي",
    "Public link copied!" : "تمّ نسخ الرابط العمومي",
    "Copy public link" : "نسخ الرابط العام",
    "Delete the public link" : "حذف الرابط العمومي",
    "Create public link share" : "إنشاء رابط مشاركة عام",
    "Share via public link" : "شارك عبر الرابط العمومي",
    "This collection does not exist" : "هذه المجموعة من العناصر collection غير موجودة",
    "An error occurred" : "طرأ هناك خطأ",
    "No picture for this day" : "لا صور لهذا اليوم",
    "Picture taken on this day will show up here." : "الصور الملتقطة في هذا اليوم ستظهر هنا.",
    "More photos from this day" : "صور أخرى من هذا اليوم",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n صور غير معينة","%n صورة غير معينة","%n صور غير معينة","%n صور غير معينة","%n صور غير معينة","%n صور غير معينة"],
    "Favorite" : "المفضلة",
    "Favorite image, open the full size \"{name}\" image" : "صورة مُفضّلة, إفتَح الحجم الكامل للصورة \"{name}\"  ",
    "Open the full size \"{name}\" image" : "افتح الصورة بالحجم الكامل \"{name}\" ",
    "Select image {imageName}" : "إختر صورة {imageName}",
    "Open the \"{name}\" folder" : "فتح المجلد \"{name}\"  ",
    "Back to {folder}" : "العودة إلى {folder} ",
    "Go back" : "عودة",
    "Share this folder" : "مشاركة هذا المجلد",
    "Dates" : "التواريخ",
    "Jump to specific date in list" : "إقفِز للتاريخ المحدد في القائمة",
    "Jump to {date}" : "إنتقِل إلى {date}",
    "Add to {destination}" : "إضافة إلى {destination}",
    "The destination folder is owned by {owner}" : "المجلد الوجهة يملكه {owner}",
    "There are no photos or videos yet!" : "لا توجد أي صور أو مقاطع فيديو حتى الآن!",
    "_{years} year ago_::_{years} years ago_" : ["سنوات {years} مضت","سنة {years} مضت","سنوات {years} مضت","سنوات {years} مضت","سنوات {years} مضت","سنوات {years} مضت"],
    "Enable squared photos view" : "تفعيل عرض الصور المربعة",
    "Delete source directory" : "إحذف الدليل المصدر",
    "Pick folder" : "إختَر مُجلّداً",
    "Select a source folder for your media" : "إختَر المجلد المصدر لوسائطك ",
    "All folders" : "كل المجلدات",
    "Add a Photos source for the timelines" : "إضافة مصادر الصور إلى الخطوط الزمنية",
    "Add folder" : "إضافة مجلد",
    "Select the default upload location for your media" : "إختَر موضع الرفع التلقائي للوسائط",
    "Home" : "الرئيسية",
    "Choose default Photos upload and Albums location" : "اختر افتراضي رفع الصور وموقع الألبومات",
    "Choose a different folder" : "إختَر مجلداً مختلفاً",
    "View" : "عرض",
    "Media folders" : "مجلدات الوسائط",
    "Choose the folders from where photos and videos are shown." : "إختَر المجلد الذي تُعرض منه الصور و المقاطع",
    "Upload folder" : "مجلد الرفع",
    "Choose the folder where photos and albums are uploaded to." : "إختَر المجلد الذي تُرفع إليه الصور و الألبومات",
    "_%n photo_::_%n photos_" : ["%n صور","%n صورة","%n صور","%n صور","%n صور","%n صور"],
    "Unselect all" : "إلغاء الاختيار للكل",
    "Add photos to this album" : "إضِف صوراً إلى هذا الألبوم",
    "Manage collaborators for this album" : "إدارة المتعاونين لهذا الألبوم",
    "Open actions menu" : "فتح قائمة الإجراءات",
    "Edit album details" : "تعديل تفاصيل الألبوم",
    "Download all files in album" : "حمّل كل ملفات الألبوم",
    "Delete album" : "حذف الألبوم",
    "Download selected files" : "تنزيل الملفات التي تمّ تحديدها",
    "Remove selection from album" : "حذف ما تمّ تحديده من الألبوم",
    "This album does not have any photos or videos yet!" : "هذا الألبوم ليس فيه أي صور أو مقاطع فيديو حتى الآن!",
    "Add photos to {albumName}" : "إضافة الصور إلى {albumName}",
    "Manage collaborators" : "إدارة المتعاونين",
    "Save collaborators for this album." : "حفظ المتعاونين لهذا الألبوم",
    "Cover photo for album {albumName}" : "صورة غلاف الألبوم {albumName}",
    "There is no album yet!" : "لا يوجد أي ألبوم حتى الآن!",
    "This person could not be found" : "تعذّر إيجاد هذا الشخص",
    "Rename person" : "تغيير اسم شخص",
    "Merge with different person" : "الدمج مع شخص آخر",
    "Download selected photos" : "تنزيل الصور المحددة",
    "Remove from favorites" : "إزالتها مِن المفضلة",
    "Remove person" : "حذف شخص",
    "Name of this person" : "أكتب اسم هذا الشخص",
    "Save." : "حفظ.",
    "Merge person" : "دمج شخص",
    "Move to different person" : "الانتقال إلي فئة شخص مختلفة",
    "_Move photo to a different person_::_Move photos to a different person_" : ["انقل الصور إلى شخص مختلف","انقل الصورة إلى شخص مختلف","انقل الصور إلى شخص مختلف","انقل الصور إلى شخص مختلف","انقل الصور إلى شخص مختلف","نقل الصور إلى فئة شخص مختلفة"],
    "_Remove photo from person_::_Remove photos from person_" : ["إزالة الصور من شخص","إزالة الصورة من شخص","إزالة الصور من شخص","إزالة الصور من شخص","إزالة الصور من شخص","إزالة الصور من فئة شخص"],
    "This might take some time depending on the size of your photo library." : "يمكن أن يستغرق هذا بعض الوقت و ذلك بحسب حجم مكتبة الصور",
    "Recognized people will show up here" : "الأشخاص الذين تمّ التعرُّف عليهم سيظهرون هنا",
    "This folder does not exist" : "هذا المجلد غير موجود",
    "Loading folders …" : "تحميل مجلدات ...",
    "No photos in here" : "لا توجد صور هنا",
    "Taken on {date} at {time}" : "أُخِذت يوم {date} الساعة {time}",
    "This place does not have any photos or videos yet!" : "هذا المكان ليس له أي صور أو مقاطع فيديو حتى الآن!",
    "Add photos to this place" : "إضافة صور إلى هذا المكان",
    "Cover photo for place {placeName}" : "صورة الغلاف للمكان {placeName}",
    "There is no place yet!" : "لا توجد أي أماكن حتى الآن!",
    "Cover photo for shared album {albumName}." : "صورة الغلاف للألبوم المشترك {albumName}.",
    "Back to tags overview" : "عودة إلى عرض الوسم",
    "No photos with this tag yet" : "لا توجد أي صورة بهذا الوسم حتى الآن",
    "No tags yet" : "لا توجد وسوم حتى الآن",
    "Photos with tags will show up here" : "سوف تظهر الصور ذات الوسوم هنا",
    "Popular tags" : "وسوم شائعة",
    "All tags" : "كل الوسوم",
    "One of the source folders does not exist" : "أحد المجلدات المصدرية غير موجود",
    "Add to album" : "إضِف إلى ألبوم",
    "Delete selection" : "حذف ما تمّ تحديده",
    "No photos or videos in here" : "لا توجد أي صور أو مقاطع فيديو هنا.",
    "Unassigned faces" : "أوجه غير معينة",
    "_%n photos_::_%n photos_" : ["%n صور","%n صور","%n صور","%n صور","%n صور","%n صور"],
    "Failed to fetch collection." : "تعذّر جلب مجموعة العناصر collection.",
    "Failed to fetch collections list." : "تعذّر جلب قائمة مجموعات العناصر collections list.",
    "Failed to fetch faces list." : "تعذّر جلب قائمة الوجوه.",
    "All your media" : "كل وسائطك",
    "Album {title}" : "الألبوم {title}",
    "Shared Albums" : "ألبومات مشتركة",
    "Shared album {title}" : "الألبوم المشترك {title}",
    "Public album {title}" : "الألبوم العام {title}",
    "Tagged photos" : "الصور الموسومة",
    "Tagged photo {title}" : "صور موسومة {title}",
    "{title}'s face" : "وجه {title}",
    "{startDate} to {endDate}" : "{startDate} إلى {endDate}",
    "Details" : "التفاصيل",
    "Failed to rename {oldName} to {faceName}." : "تعذّر تغيير تسمية {oldName} إلى {faceName}.",
    "Failed to delete {faceName}." : "تعذّر حذف {faceName}.",
    "Failed to delete {fileId}." : "تعذّر حذف {fileId}.",
    "Failed to delete {fileName}." : "تعذّر حذف {fileName}.",
    "Failed to set favorite state for {fileId}." : "تعذّر تعيين حالة \"مُفضّل\" لـ {fileId}.",
    "Failed to set favorite state for {fileName}." : "تعذّر تعيين حالة \"مُفضّل\" لـ {fileName}.",
    "Could not load photos folder" : "تعذّر رفع مجلد الصِّور",
    "One of the source folders does not exists" : "أحد المجلدات المصدرية غير موجود",
    "Add" : "إضافة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/ar.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "رابط عمومي",
    "Photos" : "الصور",
    "On This Day" : "في هذا اليوم",
    "Your memories under your control" : "ذكرياتك تحت يديك",
    "All media" : "كل الوسائط",
    "Videos" : "مقاطع الفيديو",
    "Albums" : "الألبومات",
    "Collaborative albums" : "ألبومات تعاونية",
    "People" : "الأشخاص",
    "Folders" : "المجلدات",
    "Favorites" : "المُفضّلة",
    "On this day" : "في هذا اليوم",
    "Shared with you" : "تمّت مُشارَكته معك",
    "Tags" : "الوسوم",
    "Places" : "أماكن",
    "Map" : "خريطة",
    "Photos settings" : "إعدادات الصور",
    "Mark selection as favorite" : "تحديد المفضلة",
    "Add selection to favorites" : "إضافة ما تمّ تحديده إلى المفضلة",
    "Remove selection from favorites" : "حذف ما تمّ تحديده من المفضلة",
    "Name of the album" : "اسم الألبوم",
    "Location of the album" : "موقع الألبوم",
    "Back" : "عودة",
    "Add collaborators" : "أضِف المتعاونين",
    "Save" : "حفظ",
    "Create album" : "إنشاء ألبوم",
    "Add to Album" : "إضافة إلى الألبوم",
    "Add selection to album {albumName}" : "إضافة ما تمّ تحديده إلى الألبوم {albumName}",
    "Shared by" : "تمّت مُشارَكته من قِبَل",
    "Create a new album." : "إنشِيء ألبوماً جديداً.",
    "Create new album" : "إنشاء ألبوم جديد",
    "New album" : "ألبوم جديد",
    "_%n item_::_%n photos and videos_" : ["%n صور ومقاطع الفيديو","%n عنصر","%n صور ومقاطع الفيديو","%n صور ومقاطع الفيديو","%n صور ومقاطع الفيديو","%n صور ومقاطع الفيديو"],
    "Failed to fetch collaborators list." : "تعذّر جلب قائمة المتعاونين.",
    "Failed to update album." : "تعذّر تحديث الألبوم.",
    "Add people or groups who can edit your album" : "إضِف الأشخاص أو المجموعات الذين يحق لهم تعديل ألبومك",
    "Search people or groups" : "البحث عن أشخاص أو مجموعات",
    "No recommendations. Start typing." : "لا توجد توصيات. ابدأ بالكتابة.",
    "Group" : "مجموعة",
    "Remove {collaboratorLabel} from the collaborators list" : "حذف {collaboratorLabel} من قائمة المتعاونين",
    "Copy the public link" : "إنسَخ الرابط العمومي",
    "Public link copied!" : "تمّ نسخ الرابط العمومي",
    "Copy public link" : "نسخ الرابط العام",
    "Delete the public link" : "حذف الرابط العمومي",
    "Create public link share" : "إنشاء رابط مشاركة عام",
    "Share via public link" : "شارك عبر الرابط العمومي",
    "This collection does not exist" : "هذه المجموعة من العناصر collection غير موجودة",
    "An error occurred" : "طرأ هناك خطأ",
    "No picture for this day" : "لا صور لهذا اليوم",
    "Picture taken on this day will show up here." : "الصور الملتقطة في هذا اليوم ستظهر هنا.",
    "More photos from this day" : "صور أخرى من هذا اليوم",
    "_%n photos_::_%n photos_" : ["%n صور","%n صور","%n صور","%n صور","%n صور","%n صور"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n صور غير معينة","%n صورة غير معينة","%n صور غير معينة","%n صور غير معينة","%n صور غير معينة","%n صور غير معينة"],
    "Favorite" : "المفضلة",
    "Favorite image, open the full size \"{name}\" image" : "صورة مُفضّلة, إفتَح الحجم الكامل للصورة \"{name}\"  ",
    "Open the full size \"{name}\" image" : "افتح الصورة بالحجم الكامل \"{name}\" ",
    "Select image {imageName}" : "إختر صورة {imageName}",
    "Open the \"{name}\" folder" : "فتح المجلد \"{name}\"  ",
    "Go back" : "عودة",
    "Dates" : "التواريخ",
    "Jump to specific date in list" : "إقفِز للتاريخ المحدد في القائمة",
    "Jump to {date}" : "إنتقِل إلى {date}",
    "Add to {destination}" : "إضافة إلى {destination}",
    "The destination folder is owned by {owner}" : "المجلد الوجهة يملكه {owner}",
    "There are no photos or videos yet!" : "لا توجد أي صور أو مقاطع فيديو حتى الآن!",
    "_{years} year ago_::_{years} years ago_" : ["سنوات {years} مضت","سنة {years} مضت","سنوات {years} مضت","سنوات {years} مضت","سنوات {years} مضت","سنوات {years} مضت"],
    "Enable squared photos view" : "تفعيل عرض الصور المربعة",
    "Delete source directory" : "إحذف الدليل المصدر",
    "Pick folder" : "إختَر مُجلّداً",
    "Select a source folder for your media" : "إختَر المجلد المصدر لوسائطك ",
    "All folders" : "كل المجلدات",
    "Add a Photos source for the timelines" : "إضافة مصادر الصور إلى الخطوط الزمنية",
    "Add folder" : "إضافة مجلد",
    "Select the default upload location for your media" : "إختَر موضع الرفع التلقائي للوسائط",
    "Home" : "الرئيسية",
    "Choose default Photos upload and Albums location" : "اختر افتراضي رفع الصور وموقع الألبومات",
    "Choose a different folder" : "إختَر مجلداً مختلفاً",
    "View" : "عرض",
    "Media folders" : "مجلدات الوسائط",
    "Choose the folders from where photos and videos are shown." : "إختَر المجلد الذي تُعرض منه الصور و المقاطع",
    "Upload folder" : "مجلد الرفع",
    "Choose the folder where photos and albums are uploaded to." : "إختَر المجلد الذي تُرفع إليه الصور و الألبومات",
    "_%n photo_::_%n photos_" : ["%n صور","%n صورة","%n صور","%n صور","%n صور","%n صور"],
    "Unselect all" : "إلغاء الاختيار للكل",
    "Add photos to this album" : "إضِف صوراً إلى هذا الألبوم",
    "Manage collaborators for this album" : "إدارة المتعاونين لهذا الألبوم",
    "Open actions menu" : "فتح قائمة الإجراءات",
    "Edit album details" : "تعديل تفاصيل الألبوم",
    "Download all files in album" : "حمّل كل ملفات الألبوم",
    "Delete album" : "حذف الألبوم",
    "Download selected files" : "تنزيل الملفات التي تمّ تحديدها",
    "Remove selection from album" : "حذف ما تمّ تحديده من الألبوم",
    "This album does not have any photos or videos yet!" : "هذا الألبوم ليس فيه أي صور أو مقاطع فيديو حتى الآن!",
    "Add photos to {albumName}" : "إضافة الصور إلى {albumName}",
    "Manage collaborators" : "إدارة المتعاونين",
    "Save collaborators for this album." : "حفظ المتعاونين لهذا الألبوم",
    "Cover photo for album {albumName}" : "صورة غلاف الألبوم {albumName}",
    "There is no album yet!" : "لا يوجد أي ألبوم حتى الآن!",
    "This person could not be found" : "تعذّر إيجاد هذا الشخص",
    "Rename person" : "تغيير اسم شخص",
    "Merge with different person" : "الدمج مع شخص آخر",
    "Download selected photos" : "تنزيل الصور المحددة",
    "Remove from favorites" : "إزالتها مِن المفضلة",
    "Remove person" : "حذف شخص",
    "Name of this person" : "أكتب اسم هذا الشخص",
    "Save." : "حفظ.",
    "Merge person" : "دمج شخص",
    "Move to different person" : "الانتقال إلي فئة شخص مختلفة",
    "_Move photo to a different person_::_Move photos to a different person_" : ["انقل الصور إلى شخص مختلف","انقل الصورة إلى شخص مختلف","انقل الصور إلى شخص مختلف","انقل الصور إلى شخص مختلف","انقل الصور إلى شخص مختلف","نقل الصور إلى فئة شخص مختلفة"],
    "_Remove photo from person_::_Remove photos from person_" : ["إزالة الصور من شخص","إزالة الصورة من شخص","إزالة الصور من شخص","إزالة الصور من شخص","إزالة الصور من شخص","إزالة الصور من فئة شخص"],
    "This might take some time depending on the size of your photo library." : "يمكن أن يستغرق هذا بعض الوقت و ذلك بحسب حجم مكتبة الصور",
    "Recognized people will show up here" : "الأشخاص الذين تمّ التعرُّف عليهم سيظهرون هنا",
    "This folder does not exist" : "هذا المجلد غير موجود",
    "Loading folders …" : "تحميل مجلدات ...",
    "No photos in here" : "لا توجد صور هنا",
    "Taken on {date} at {time}" : "أُخِذت يوم {date} الساعة {time}",
    "This place does not have any photos or videos yet!" : "هذا المكان ليس له أي صور أو مقاطع فيديو حتى الآن!",
    "Add photos to this place" : "إضافة صور إلى هذا المكان",
    "Cover photo for place {placeName}" : "صورة الغلاف للمكان {placeName}",
    "There is no place yet!" : "لا توجد أي أماكن حتى الآن!",
    "Cover photo for shared album {albumName}" : "صُورَة الغِلاف للألبوم المُشتَرَك {albumName}",
    "Back to tags overview" : "عودة إلى عرض الوسم",
    "No photos with this tag yet" : "لا توجد أي صورة بهذا الوسم حتى الآن",
    "No tags yet" : "لا توجد وسوم حتى الآن",
    "Photos with tags will show up here" : "سوف تظهر الصور ذات الوسوم هنا",
    "Popular tags" : "وسوم شائعة",
    "All tags" : "كل الوسوم",
    "One of the source folders does not exist" : "أحد المجلدات المصدرية غير موجود",
    "Add to album" : "إضِف إلى ألبوم",
    "Delete selection" : "حذف ما تمّ تحديده",
    "No photos or videos in here" : "لا توجد أي صور أو مقاطع فيديو هنا.",
    "Unassigned faces" : "أوجه غير معينة",
    "Failed to fetch collection." : "تعذّر جلب مجموعة العناصر collection.",
    "Failed to fetch collections list." : "تعذّر جلب قائمة مجموعات العناصر collections list.",
    "Failed to fetch faces list." : "تعذّر جلب قائمة الوجوه.",
    "All your media" : "كل وسائطك",
    "Album {title}" : "الألبوم {title}",
    "Shared Albums" : "ألبومات مشتركة",
    "Shared album {title}" : "الألبوم المشترك {title}",
    "Public album {title}" : "الألبوم العام {title}",
    "Tagged photos" : "الصور الموسومة",
    "Tagged photo {title}" : "صور موسومة {title}",
    "{title}'s face" : "وجه {title}",
    "{startDate} to {endDate}" : "{startDate} إلى {endDate}",
    "Details" : "التفاصيل",
    "Failed to delete {fileBaseName}" : "تعذّر حذف {fileBaseName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "تعذر تغيير تسمية {currentCollectionFileName} إلى {newCollectionFileName}",
    "Failed to delete {collectionFileName}" : "تعذّر حذف {collectionFileName}",
    "Failed to rename {oldName} to {faceName}" : "تعذر تغيير تسمية {oldName} إلى {faceName}",
    "Failed to delete {faceName}" : "تعذّر حذف{faceName}",
    "Failed to delete {fileId}" : "تعذّر حذف {fileId}",
    "Failed to delete {fileName}" : "تعذّر حذف{fileName}",
    "Failed to set favorite state for {fileId}" : "تعذّر تعيين الحالة المُفضَّلة لـ{fileId}",
    "Failed to set favorite state for {fileName}" : "تعذّر تعيين الحالة المُفضَّلة لـ{fileName}",
    "Could not load photos folder" : "تعذّر رفع مجلد الصِّور",
    "Back to {folder}" : "العودة إلى {folder} ",
    "Share this folder" : "مشاركة هذا المجلد",
    "One of the source folders does not exists" : "أحد المجلدات المصدرية غير موجود",
    "Add" : "إضافة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
